%global base_name digester
%global short_name commons-%{base_name}

Name:          apache-%{short_name}
Version:       1.8.1
Release:       %mkrel 11
Summary:       XML to Java object mapping module
Group:         Development/Java
License:       ASL 2.0
URL:           http://commons.apache.org/%{base_name}/
Source0:       http://archive.apache.org/dist/commons/%{base_name}/source/%{short_name}-%{version}-src.tar.gz
BuildArch:     noarch
BuildRequires: java-devel
BuildRequires: jpackage-utils
BuildRequires: apache-commons-beanutils >= 1.8
BuildRequires: apache-commons-logging >= 1.1.1
BuildRequires: maven2-plugin-antrun
BuildRequires: maven2-plugin-assembly
BuildRequires: maven2-plugin-compiler
BuildRequires: maven2-plugin-idea
BuildRequires: maven2-plugin-install
BuildRequires: maven2-plugin-jar
BuildRequires: maven2-plugin-javadoc
BuildRequires: maven2-plugin-resources
BuildRequires: maven-doxia-sitetools
BuildRequires: maven-plugin-bundle
BuildRequires: maven-surefire-maven-plugin
BuildRequires: maven-surefire-provider-junit
Requires:      java
Requires:      jpackage-utils
Requires(post):jpackage-utils
Requires(postun):jpackage-utils
Requires:      apache-commons-beanutils >= 1.8
Requires:      apache-commons-logging >= 1.1.1

Provides:      jakarta-%{short_name} = %{version}-%{release}
Obsoletes:     jakarta-%{short_name} < %{version}-%{release}

%description
Many projects read XML configuration files to provide initialization of
various Java objects within the system. There are several ways of doing this,
and the Digester component was designed to provide a common implementation
that can be used in many different projects

%package rss
Summary:       %{name} RSS (Really Simple Syndication)
Group:         Development/Java
BuildRequires: ant
BuildRequires: junit
Requires:      jpackage-utils
Requires:      apache-%{short_name} = %{version}-%{release}

%description rss
XML to Java object mapping module.

This package contains the example for parsing RSS (Really Simple
Syndication) newsfeeds, which was originally included directly in the
commons-digester.jar file, in package "org.apache.commons.digester.rss".
The package name has not been changed, so the only impact on applications
relying on these classes will be the need to include an additional JAR
file (commons-digester-rss.jar) in their classpath.

%package javadoc
Summary:       API documentation for %{name}
Group:         Development/Java
Requires:      jpackage-utils
Obsoletes:     jakarta-%{short_name}-javadoc < %{version}-%{release}

%description javadoc
%{summary}.

%prep
%setup -q -n %{short_name}-%{version}-src

sed -i 's/\r//' RELEASE-NOTES*.txt LICENSE.txt NOTICE.txt

%build
export MAVEN_REPO_LOCAL=$(pwd)/.m2/repository
mkdir -p $MAVEN_REPO_LOCAL

mvn-jpp -Dmaven.compile.source=1.5 -Dmaven.compile.target=1.5 \
  -Dmaven.repo.local=$MAVEN_REPO_LOCAL install javadoc:javadoc

export CLASSPATH=""
CLASSPATH=$CLASSPATH:$(build-classpath commons-logging commons-beanutils junit)
CLASSPATH=$CLASSPATH:`pwd`/target/%{short_name}-%{version}.jar
(
  cd src/examples/rss
  ant dist
)

%install
rm -rf %{buildroot}

# jars
mkdir -p %{buildroot}%{_javadir}
install -pm 0644 target/%{short_name}-%{version}.jar \
  %{buildroot}%{_javadir}/%{short_name}-%{version}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|%{short_name}|%{name}|g"`; done)
(cd %{buildroot}%{_javadir} && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

install -pm 0644 src/examples/rss/dist/%{short_name}-rss.jar \
  %{buildroot}%{_javadir}/%{name}-rss-%{version}.jar

(
  cd %{buildroot}%{_javadir}
  ln -sf %{name}-rss-%{version}.jar %{name}-rss.jar
  ln -sf %{name}-rss-%{version}.jar %{short_name}-rss-%{version}.jar
  ln -sf %{name}-rss-%{version}.jar %{short_name}-rss.jar
)

# javadocs
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}-%{version}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}-%{version}
ln -s %{name}-%{version} %{buildroot}%{_javadocdir}/%{name}

# pom
install -pD -T -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{short_name}.pom
%add_to_maven_depmap org.apache.commons %{short_name} %{version} JPP %{short_name}

# following line is only for backwards compatibility. New packages
# should use proper groupid org.apache.commons
%add_to_maven_depmap %{short_name} %{short_name} %{version} JPP %{short_name}

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%doc LICENSE.txt NOTICE.txt RELEASE-NOTES*
%{_mavendepmapfragdir}/*
%{_mavenpomdir}/*
%{_javadir}/%{name}-%{version}.jar
%{_javadir}/%{name}.jar
%{_javadir}/%{short_name}-%{version}.jar
%{_javadir}/%{short_name}.jar

%files rss
%{_javadir}/%{name}-rss-%{version}.jar
%{_javadir}/%{name}-rss.jar
%{_javadir}/%{short_name}-rss-%{version}.jar
%{_javadir}/%{short_name}-rss.jar

%files javadoc
%{_javadocdir}/%{name}-%{version}
%{_javadocdir}/%{name}


%changelog
* Thu Jul 28 2011 dmorgan <dmorgan> 1.8.1-11.mga2
+ Revision: 130014
- Clean spec file

  + gil <gil>
    - add rss sub package

* Wed Apr 27 2011 dmorgan <dmorgan> 1.8.1-9.mga1
+ Revision: 92231
- Rebuild after bootstrapping
- imported package apache-commons-digester


* Mon Feb 07 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.1-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Fri May 21 2010 Mat Booth <fedora@matbooth.co.uk> - 1.8.1-7
- Correct dep-map names.

* Fri May 14 2010 Mat Booth <fedora@matbooth.co.uk> - 1.8.1-6
- Obsolete jakarta javadoc package.
- Keep legacy depmap around.

* Thu May 13 2010 Mat Booth <fedora@matbooth.co.uk> - 1.8.1-5
- Drop really old obsoletes/provides on short_name.
- Fix requires.

* Tue May 11 2010 Mat Booth <fedora@matbooth.co.uk> - 1.8.1-4
- Not ready for auto OSGi depsolving yet in this package.
- Rename package (jakarta-commons-digester->apache-commons-digester).

* Tue Dec 8 2009 Mat Booth <fedora@matbooth.co.uk> - 1.8.1-3
- Enable OSGi automatic depsolving (from Alphonse Van Assche).

* Sun Nov 8 2009 Mat Booth <fedora@matbooth.co.uk> - 1.8.1-2
- Fix build failure due to targeting too old a JRE
- Add missing doxia build req

* Sun Nov 8 2009 Mat Booth <fedora@matbooth.co.uk> - 1.8.1-1
- Update to 1.8.1
- Rewrite spec file to build using upstream-preferred maven instead of ant
- Install pom and add to maven dep-map
- Fix javadoc package requires

* Mon Aug 10 2009 Ville Skyttä <ville.skytta@iki.fi> - 0:1.7-10.3
- Convert specfile to UTF-8.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.7-9.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:1.7-8.3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul  9 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0:1.7-7.3
- fix license tag
- drop repotag

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0:1.7-7jpp.2
- Autorebuild for GCC 4.3

* Fri Sep 07 2007 Matt Wringe <mwringe@redhat.com> - 0:1.7-6jpp.2
- Fix unowned dir (/usr/lib/gcj/jakarta-commons-digester)

* Mon Jan 22 2007 Vivek Lakshmanan <vivekl at redhat.com> - 0:1.7-6jpp.1
- Resynch with JPP release

* Tue Jan 16 2007 Vivek Lakshmanan <vivekl at redhat.com> - 0:1.7-5jpp.3
- Update component-info.xml to add scm and tag attribute instead of a comment
- Remove the export of a versioned jar

* Tue Jan 9 2007 Vivek Lakshmanan <vivekl at redhat.com> - 0:1.7-5jpp.2
- Upgrade to latest from JPP and FC6
- Remove old RHUG specific trigger
- Add support for conditional build of repolib package
- Build repolib package by default

* Thu Aug 10 2006 Matt Wringe <mwringe at redhat.com> - 0:1.7-5jpp.1
- Merge with upstream version:
 - Add missing requires for javadoc

* Thu Aug 10 2006 Karsten Hopp <karsten@redhat.de> 1.7-4jpp_3fc
- Requires(post/postun): coreutils

* Sat Jul 22 2006 Jakub Jelinek <jakub@redhat.com> - 0:1.7-4jpp_2fc
- Rebuilt

* Wed Jul 19 2006 Matt Wringe <mwringe at redhat.com> - 0:1.7-4jpp_1fc
- Merged with upstream version

* Wed Jul 19 2006 Matt Wringe <mwringe at redhat.com> - 0:1.7-4jpp
- Removed separate definition of name, version and release.

* Mon Jul 17 2006 Matt Wringe <mwringe at redhat.com> - 0:1.7-3jpp
- Added conditional native compiling

* Wed Apr 26 2006 Fernando Nasser <fnasser@redhat.com> - 0:1.7-2jpp
- First JPP 1.7 build

* Tue Jul 26 2005 Fernando Nasser <fnasser@redhat.com> - 0:1.7-1jpp
- Upgrade to 1.7

* Thu Nov 26 2004 Fernando Nasser <fnasser@redhat.com> - 0:1.6-2jpp
- Rebuild so that rss package is included

* Thu Oct 21 2004 Fernando Nasser <fnasser@redhat.com> - 0:1.6-1jpp
- Upgrade to 1.6

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:1.5-4jpp
- Rebuild with ant-1.6.2

* Fri May 09 2003 David Walluck <david@anti-microsoft.org> 0:1.5-3jpp
- update for JPackage 1.5

* Thu May 08 2003 Henri Gomez <hgomez@users.sourceforge.net> 1.5-2jpp
- used correct JPP 1.5 spec file

* Thu May 08 2003 Henri Gomez <hgomez@users.sourceforge.net> 1.5-2jpp
- 1.5

